/*
 * FreeSWITCH Modular Media Switching Software Library / Soft-Switch Application
 * Copyright (C) 2005-2014, Anthony Minessale II <anthm@freeswitch.org>
 *
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is FreeSWITCH Modular Media Switching Software Library / Soft-Switch Application
 *
 * The Initial Developer of the Original Code is
 * Piotr Gregor <piotr@freeswitch.com> <piotr@signalwire.com>
 *
 * Portions created by the Initial Developer are Copyright (C)
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Piotr Gregor <piotr@freeswitch.org> <piotr@signalwire.com>
 *
 * mod_red.c -- The redundancy encoder/decoder (RFC 2198, RFC 5109)
 *
 */

#include "switch.h"
#include "switch_red.h"


SWITCH_MODULE_LOAD_FUNCTION(mod_red_load);
SWITCH_MODULE_DEFINITION(mod_red, mod_red_load, NULL, NULL);


static switch_status_t switch_codec_red_init(switch_codec_t *codec, switch_codec_flag_t flags, const switch_codec_settings_t *codec_settings)
{
	return SWITCH_STATUS_SUCCESS;
}

static switch_status_t switch_codec_red_destroy(switch_codec_t *codec)
{

	codec->private_info = NULL;
	return SWITCH_STATUS_SUCCESS;
}

static switch_status_t switch_codec_red_encode(switch_codec_t *codec,
										  switch_codec_t *other_codec,
										  void *decoded_data,
										  uint32_t decoded_data_len,
										  uint32_t decoded_rate, void *encoded_data, uint32_t *encoded_data_len, uint32_t *encoded_rate,
										  unsigned int *flag)
{
	return SWITCH_STATUS_SUCCESS;
}

static switch_status_t switch_codec_red_decode(switch_codec_t *codec,
										  switch_codec_t *other_codec,
										  void *encoded_data,
										  uint32_t encoded_data_len,
										  uint32_t encoded_rate, void *decoded_data, uint32_t *decoded_data_len, uint32_t *decoded_rate,
										  unsigned int *flag)
{
	return SWITCH_STATUS_SUCCESS;
}

SWITCH_MODULE_LOAD_FUNCTION(mod_red_load)
{
	switch_codec_interface_t *codec_interface;

	*module_interface = switch_loadable_module_create_module_interface(pool, modname);
	SWITCH_ADD_CODEC(codec_interface, "RED");

	switch_core_codec_add_implementation(pool, codec_interface,
			SWITCH_CODEC_TYPE_VIDEO, SWITCH_RED_PT, "red", NULL, 90000, 90000, 0,
			0, 0, 0, 0, 1, 1, switch_codec_red_init, switch_codec_red_encode, switch_codec_red_decode, switch_codec_red_destroy);
	/*switch_core_codec_add_implementation(pool, codec_interface,
			SWITCH_CODEC_TYPE_VIDEO, SWITCH_RED_PT, "red", NULL, 48000, 48000, 0,
			0, 0, 0, 0, 1, 1, switch_codec_red_init, switch_codec_red_encode, switch_codec_red_decode, switch_codec_red_destroy);
*/
	return SWITCH_STATUS_SUCCESS;
}

/* For Emacs:
 * Local Variables:
 * mode:c
 * indent-tabs-mode:t
 * tab-width:4
 * c-basic-offset:4
 * End:
 * For VIM:
 * vim:set softtabstop=4 shiftwidth=4 tabstop=4 noet:
 */

